@@ -1,9 +1,7 @@
-from prefect import task
 import numpy as np
 import pandas as pd
 
 
-@task
 def filter_coordinate_bounds(coordinates: list, radius: float) -> pd.DataFrame:
     """
     Filters list for coordinates with given radius.
