@@ -1,11 +1,7 @@
-from typing import Tuple
-
 from aicsimageio import AICSImage
-from prefect import task
 
 
-@task
-def get_image_bounds(image: AICSImage) -> Tuple[int, int, int]:
+def get_image_bounds(image: AICSImage) -> tuple[int, int, int]:
     """
     Extracts image bounds in the x, y, and z directions.
 
