@@ -1,8 +1,6 @@
-from prefect import task
 import pandas as pd
 
 
-@task
 def exclude_selected_ids(samples: pd.DataFrame, exclude: list[int]) -> pd.DataFrame:
     """
     Filters samples to exclude given ids.
