@@ -1,12 +1,8 @@
-from typing import List
-
-from prefect import task
-from aicsimageio import AICSImage
 import pandas as pd
+from aicsimageio import AICSImage
 
 
-@task
-def get_image_samples(image: AICSImage, sample_indices: List, channel: int) -> pd.DataFrame:
+def get_image_samples(image: AICSImage, sample_indices: list, channel: int) -> pd.DataFrame:
     """
     Sample image at given indices into list of (id, x, y, z) samples.
 
