@@ -1,8 +1,6 @@
-from prefect import task
 import pandas as pd
 
 
-@task
 def include_selected_ids(samples: pd.DataFrame, include: list[int]) -> pd.DataFrame:
     """
     Filters samples to include given ids.
