@@ -1,10 +1,8 @@
 from typing import Optional
 
-from prefect import task
 import pandas as pd
 
 
-@task
 def scale_sample_coordinates(
     samples: pd.DataFrame,
     coordinate_type: Optional[str],
